@@ -14,7 +14,7 @@ use CPAN::Audit::Version;
 use CPAN::Audit::Query;
 use CPAN::Audit::DB;
 
-our $VERSION = '20230601.002';
+our $VERSION = '20230826.001';
 
 sub new {
 	my( $class, %params ) = @_;
@@ -26,7 +26,7 @@ sub new {
 
 	$self->_handle_exclude_file if $self->{exclude_file};
 
-	$self->{db}       = CPAN::Audit::DB->db;
+	$self->{db}     //= CPAN::Audit::DB->db;
 
 	$self->{filter}   = CPAN::Audit::Filter->new( exclude => $args{exclude} );
 	$self->{query}    = CPAN::Audit::Query->new( db => $self->{db} );
@@ -54,7 +54,7 @@ sub _handle_exclude_file {
 }
 
 sub command_module {
-	my ( $self, $dists, $module, $version_range ) = @_;
+	my ( $self, $dists, $queried, $module, $version_range ) = @_;
 	return "Usage: module <module> [version-range]" unless $module;
 
 	my $distname = $self->{db}->{module2dist}->{$module};
@@ -63,13 +63,14 @@ sub command_module {
 		return "Module '$module' is not in database";
 	}
 
+	push @{ $queried->{$distname} }, $module;
 	$dists->{$distname} = $version_range // '';
 
 	return;
 }
 
 sub command_release {
-	my ( $self, $dists, $distname, $version_range ) = @_;
+	my ( $self, $dists, $queried, $distname, $version_range ) = @_;
 	return "Usage: dist|release <module> [version-range]"
 		unless $distname;
 
@@ -83,7 +84,7 @@ sub command_release {
 }
 
 sub command_show {
-	my ( $self, $dists, $advisory_id ) = @_;
+	my ( $self, $dists, $queried, $advisory_id ) = @_;
 	return "Usage: show <advisory-id>" unless $advisory_id;
 
 	my ($release) = $advisory_id =~ m/^CPANSA-(.*?)-(\d+)-(\d+)$/;
@@ -104,13 +105,13 @@ sub command_show {
 }
 
 sub command_modules {
-	my ($self, $dists, @modules) = @_;
-	return "Usage: modules '<module>[,version-range]' '<module>[,version-range]'" unless @modules;
+	my ($self, $dists, $queried, @modules) = @_;
+	return "Usage: modules '<module>[;version-range]' '<module>[;version-range]'" unless @modules;
 
 	foreach my $module ( @modules ) {
 		my ($name, $version) = split /;/, $module;
 
-		my $failed = $self->command_module( $dists, $name, $version // '' );
+		my $failed = $self->command_module( $dists, $queried, $name, $version // '' );
 
 		if ( $failed ) {
 			$self->verbose( $failed );
@@ -122,7 +123,7 @@ sub command_modules {
 }
 
 sub command_deps {
-	my ($self, $dists, $dir) = @_;
+	my ($self, $dists, $queried, $dir) = @_;
 	$dir = '.' unless defined $dir;
 
 	return "Usage: deps <dir>" unless -d $dir;
@@ -136,6 +137,8 @@ sub command_deps {
 		  || $self->{db}->{module2dist}->{ $dep->{module} };
 		next unless $dist;
 
+		push @{ $queried->{$dist} }, $dep->{module} if !$dep->{dist};
+
 		$dists->{$dist} = $dep->{version};
 	}
 
@@ -143,7 +146,7 @@ sub command_deps {
 }
 
 sub command_installed {
-	my ($self, $dists, @args) = @_;
+	my ($self, $dists, $queried, @args) = @_;
 
 	$self->verbose('Collecting all installed modules. This can take a while...');
 
@@ -193,7 +196,8 @@ sub command {
 		errors => [],
 		dists => {},
 	);
-	my $dists = $report{dists};
+	my $dists  = $report{dists};
+	my $queried = {};
 
 	if (!$self->{no_corelist}
 		&& (   $command eq 'dependencies'
@@ -213,7 +217,7 @@ sub command {
 
 	if ( exists $command_table->{$command} ) {
 		my $method = $command_table->{$command};
-		push @{ $report{errors} }, $self->$method( $dists, @args );
+		push @{ $report{errors} }, $self->$method( $dists, $queried, @args );
 		return \%report if $command eq 'show';
 	}
 	else {
@@ -236,8 +240,9 @@ sub command {
 
 			if ( @advisories ) {
 				$dists->{$distname} = {
-					advisories => \@advisories,
-					version    => $version_range,
+					advisories      => \@advisories,
+					version         => $version_range,
+					queried_modules => $queried->{$distname} || [],
 				};
 			}
 			else {
